@@ -1,13 +1,15 @@
 #! coding:utf-8
 
 from sqlalchemy import Column, Integer, MetaData, String, Table,\
-    bindparam, exc, func, insert, select, column, text, table
+    bindparam, exc, func, insert, select, column, text, table,\
+    Sequence
 from sqlalchemy.dialects import mysql, postgresql
 from sqlalchemy.engine import default
 from sqlalchemy.testing import AssertsCompiledSQL,\
     assert_raises_message, fixtures, eq_, expect_warnings
 from sqlalchemy.sql import crud
 
+
 class _InsertTestBase(object):
 
     @classmethod
@@ -23,8 +25,7 @@ class _InsertTestBase(object):
               Column('id', Integer, primary_key=True),
               Column('x', Integer, default=10),
               Column('y', Integer, server_default=text('5')),
-              Column('z', Integer, default=lambda: 10)
-            )
+              Column('z', Integer, default=lambda: 10))
 
 
 class InsertTest(_InsertTestBase, fixtures.TablesTest, AssertsCompiledSQL):
@@ -238,6 +239,24 @@ class InsertTest(_InsertTestBase, fixtures.TablesTest, AssertsCompiledSQL):
             checkparams={"name_1": "foo"}
         )
 
+    def test_insert_from_select_seq(self):
+        m = MetaData()
+
+        t1 = Table(
+            't', m,
+            Column('id', Integer, Sequence('id_seq'), primary_key=True),
+            Column('data', String)
+        )
+
+        stmt = t1.insert().from_select(('data', ), select([t1.c.data]))
+
+        self.assert_compile(
+            stmt,
+            "INSERT INTO t (data, id) SELECT t.data, "
+            "nextval('id_seq') AS next_value_1 FROM t",
+            dialect=postgresql.dialect()
+        )
+
     def test_insert_from_select_cte_one(self):
         table1 = self.tables.mytable
 
@@ -407,7 +426,6 @@ class InsertTest(_InsertTestBase, fixtures.TablesTest, AssertsCompiledSQL):
             "SELECT mytable.foo, :bar AS anon_1 FROM mytable"
         )
 
-
     def test_insert_mix_select_values_exception(self):
         table1 = self.tables.mytable
         sel = select([table1.c.myid, table1.c.name]).where(
@@ -598,6 +616,23 @@ class InsertTest(_InsertTestBase, fixtures.TablesTest, AssertsCompiledSQL):
                 dialect=d
             )
 
+    def test_anticipate_no_pk_lower_case_table(self):
+        t = table(
+            't',
+            Column(
+                'id', Integer, primary_key=True, autoincrement=False),
+            Column('notpk', String(10), nullable=True)
+        )
+        with expect_warnings(
+            "Column 't.id' is marked as a member.*"
+            "may not store NULL.$"
+        ):
+            self.assert_compile(
+                t.insert(),
+                "INSERT INTO t () VALUES ()",
+                params={}
+            )
+
 
 class InsertImplicitReturningTest(
         _InsertTestBase, fixtures.TablesTest, AssertsCompiledSQL):
@@ -647,6 +682,18 @@ class InsertImplicitReturningTest(
                 'othername_m0': 'foo'}
         )
 
+    def test_insert_multiple_values_literal_binds(self):
+        ins = self.tables.myothertable.insert().values([
+            {"othername": "foo"},
+            {"othername": "bar"},
+        ])
+        self.assert_compile(
+            ins,
+            "INSERT INTO myothertable (othername) VALUES ('foo'), ('bar')",
+            checkparams={},
+            literal_binds=True
+        )
+
     def test_insert_multiple_values_return_defaults(self):
         # TODO: not sure if this should raise an
         # error or what
